@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import pytest
 
-from efc.rpn_builder.parser.operands import BadReference, NumErrorOperand
+from efc.rpn_builder.parser.operands import BadReference, NumErrorOperand, ValueNotAvailable
 from .mock import ExcelMock, get_calculator
 
 
@@ -46,6 +46,15 @@ def test_IF(calc):
     assert calc('IF(\'Sheet 1\'!A3 = 4,\'Sheet 1\'!C3, 0)', 'Yet another sheet').value == 8
 
 
+def test_IFS(calc):
+    assert calc('IFS(FALSE,1,FALSE,2,TRUE,3)', 'Yet another sheet').value == 3
+    assert calc('IFS(TRUE,1,FALSE,2,TRUE,3)', 'Yet another sheet').value == 1
+    assert calc('IFS(FALSE,1,TRUE,2,TRUE,3)', 'Yet another sheet').value == 2
+
+    with pytest.raises(ValueNotAvailable):
+        assert calc('IFS(FALSE,1,FALSE,2,FALSE,3)', 'Yet another sheet').value == 1
+
+
 def test_IFERROR(calc):
     assert calc('IFERROR(5/0,1)', 'Yet another sheet').value == 1
     assert calc('IFERROR(5+6, 0)', 'Yet another sheet').value == 11
